This function removes from freeze directory the files that do not match the language code to avoid using the wrong cache values for code computations.
This function removes from freeze directory the files that do not match the language code to avoid using the wrong cache values for code computations.